@@ -302,7 +302,7 @@ function alis_install_package() {
           ALL_PACKAGES+=( git )
           ;;
         gnome)
-          ALL_PACKAGES+=(gnome gnome-extra matcha-gtk-theme xcursor-breeze papirus-maia-icon-theme-git noto-fonts ttf-liberation gnome-shell-extensions gnome-shell-extension-topicons-plus chrome-gnome-shell evolution-ews evolution-on)
+          ALL_PACKAGES+=(gnome gnome-extra matcha-gtk-theme xcursor-breeze papirus-maia-icon-theme-git ttf-dejavu noto-fonts ttf-liberation gnome-shell-extensions gnome-shell-extension-topicons-plus chrome-gnome-shell evolution-ews evolution-on)
           ALL_CONFIG+=(gnome_terminal_transparency_user gnome_system gnome_user)
           ;;
         docker)
@@ -363,6 +363,10 @@ function pre_conf_packages() {
       systemctl start gdm.service
     fi
 
+    ln -s /etc/fonts/conf.avail/70-no-bitmaps.conf /etc/fonts/conf.d
+    ln -s /etc/fonts/conf.avail/10-sub-pixel-rgb.conf /etc/fonts/conf.d
+    ln -s /etc/fonts/conf.avail/11-lcdfilter-default.conf /etc/fonts/conf.d
+
     mkdir -p /etc/dconf/profile
     cat <<'EOT' >/etc/dconf/profile/user
 user-db:user
